@@ -1,3 +1,4 @@
 # Trick to suppress some check warnings
 globalVariables(c("%>%", "identifier", "method", "variable", "value", "sd", 
-  "SD", "N", "median", "M", "pct", "DV", "group", "term", "terms"))
\ No newline at end of file
+  "SD", "N", "median", "M", "pct", "DV", "group", "term", "terms", ".", "n",
+  "column"))
\ No newline at end of file
