@@ -4,6 +4,7 @@
 #'
 #' @param x A tidystats list.
 #' @param path Path or connection to write to.
+#' @param digits The number of decimal places to use.
 #' 
 #' @examples 
 #' # Load dplyr for access to the piping operator
@@ -37,7 +38,7 @@
 #' write_stats(results, file.path(dir, "results.json"))
 #'
 #' @export
-write_stats <- function(x, path) {
+write_stats <- function(x, path, digits = 6) {
 
   # Check whether the arguments are supplied
   if (!is.list(x)) {
@@ -48,5 +49,6 @@ write_stats <- function(x, path) {
   }
 
   # Write to disk
-  jsonlite::write_json(x, path = path, pretty = TRUE, auto_unbox = TRUE)
+  jsonlite::write_json(x, path = path, pretty = TRUE, auto_unbox = TRUE, 
+    digits = digits)
 }
